package com.smartframework.core.config;

package ..deTemp.1731130275432;

import com.sun.crypto.provider.SunJCE;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.security.Key;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.Security;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;

public class PropertiesEncryptor {
  public static void main(String[] args) throws Exception {
    if (args == null || (args.length != 3 && args.length != 2)) {
      System.err.println("命令使用方法:java -jar PropertiesEncryptor.jar operatorType(key|encrypt|decrypt) keyFilePath [propertiesFileLocation]");
      return;
    } 
    String operatorType = args[0];
    String keyFilePath = args[1];
    String propertiesFileLocation = (args.length == 3) ? args[2] : null;
    execute(keyFilePath, propertiesFileLocation, operatorType);
  }
  
  public static Key createKey() throws NoSuchAlgorithmException {
    Security.insertProviderAt(new SunJCE(), 1);
    KeyGenerator generator = KeyGenerator.getInstance("DES");
    generator.init(new SecureRandom());
    Key key = generator.generateKey();
    return key;
  }
  
  public static Key getKey(InputStream is) {
    try {
      ObjectInputStream ois = new ObjectInputStream(is);
      return (Key)ois.readObject();
    } catch (Exception e) {
      e.printStackTrace();
      throw new RuntimeException(e);
    } 
  }
  
  private static byte[] doEncrypt(Key key, byte[] data) {
    try {
      Cipher cipher = Cipher.getInstance("DES/ECB/PKCS5Padding");
      cipher.init(1, key);
      return cipher.doFinal(data);
    } catch (Exception e) {
      e.printStackTrace();
      throw new RuntimeException(e);
    } 
  }
  
  public static InputStream doDecrypt(Key key, InputStream in) {
    try {
      Cipher cipher = Cipher.getInstance("DES/ECB/PKCS5Padding");
      cipher.init(2, key);
      ByteArrayOutputStream bout = new ByteArrayOutputStream();
      byte[] tmpbuf = new byte[1024];
      int count = 0;
      while ((count = in.read(tmpbuf)) != -1) {
        bout.write(tmpbuf, 0, count);
        tmpbuf = new byte[1024];
      } 
      in.close();
      byte[] orgData = bout.toByteArray();
      byte[] raw = cipher.doFinal(orgData);
      return new ByteArrayInputStream(raw);
    } catch (Exception e) {
      e.printStackTrace();
      throw new RuntimeException(e);
    } 
  }
  
  private static void execute(String keyFilePath, String sourceFilePath, String operatorType) throws Exception {
    if (operatorType.equalsIgnoreCase("key")) {
      Key key = createKey();
      ObjectOutputStream oos = new ObjectOutputStream(new FileOutputStream(keyFilePath));
      oos.writeObject(key);
      oos.close();
      System.out.println("成功生成密钥文件" + keyFilePath);
    } else if (operatorType.equalsIgnoreCase("encrypt")) {
      File file = new File(sourceFilePath);
      FileInputStream in = new FileInputStream(file);
      ByteArrayOutputStream bout = new ByteArrayOutputStream();
      byte[] tmpbuf = new byte[1024];
      int count = 0;
      while ((count = in.read(tmpbuf)) != -1) {
        bout.write(tmpbuf, 0, count);
        tmpbuf = new byte[1024];
      } 
      in.close();
      byte[] orgData = bout.toByteArray();
      Key key = getKey(new FileInputStream(keyFilePath));
      byte[] raw = doEncrypt(key, orgData);
      file = new File(file.getParent() + "\\en_" + file.getName());
      FileOutputStream out = new FileOutputStream(file);
      out.write(raw);
      out.close();
      System.out.println("成功加密，加密文件位于:" + file.getAbsolutePath());
    } else if (operatorType.equalsIgnoreCase("decrypt")) {
      File file = new File(sourceFilePath);
      FileInputStream fis = new FileInputStream(file);
      Key key = getKey(new FileInputStream(keyFilePath));
      InputStream raw = doDecrypt(key, fis);
      ByteArrayOutputStream bout = new ByteArrayOutputStream();
      byte[] tmpbuf = new byte[1024];
      int count = 0;
      while ((count = raw.read(tmpbuf)) != -1) {
        bout.write(tmpbuf, 0, count);
        tmpbuf = new byte[1024];
      } 
      raw.close();
      byte[] orgData = bout.toByteArray();
      file = new File(file.getParent() + "\\rs_" + file.getName());
      FileOutputStream fos = new FileOutputStream(file);
      fos.write(orgData);
      System.out.println("成功解密，解密文件位于:" + file.getAbsolutePath());
    } 
  }
}
